diff --git a/src/gprs_rlcmac_data.cpp b/src/gprs_rlcmac_data.cpp
index d60a1a1..d632ec4 100644
--- a/src/gprs_rlcmac_data.cpp
+++ b/src/gprs_rlcmac_data.cpp
@@ -1787,7 +1787,6 @@ static void gprs_rlcmac_downlink_assignment(gprs_rlcmac_tbf *tbf, uint8_t poll,
 	int plen;
 
 	debug_diagram(tbf->diag, "IMM.ASS (PCH)");
-	LOGP(DRLCMAC, LOGL_INFO, "TX: START TFI: %u TLLI: 0x%08x Immediate Assignment Downlink (PCH)\n", tbf->tfi, tbf->tlli);
 	bitvec *immediate_assignment = bitvec_alloc(22); /* without plen */
 	bitvec_unhex(immediate_assignment, "2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b2b");
 	/* use request reference that has maximum distance to current time,
@@ -1796,7 +1795,16 @@ static void gprs_rlcmac_downlink_assignment(gprs_rlcmac_tbf *tbf, uint8_t poll,
 		(tbf->pdch[tbf->first_ts]->last_rts_fn + 21216) % 2715648, tbf->ta,
 		tbf->arfcn, tbf->first_ts, tbf->tsc, tbf->tfi, 0, tbf->tlli, poll,
 		tbf->poll_fn, 0, bts->alpha, bts->gamma, -1);
-	pcu_l1if_tx_pch(immediate_assignment, plen, imsi);
+	if (imsi == NULL)
+	{
+		LOGP(DRLCMAC, LOGL_INFO, "TX: START TFI: %u TLLI: 0x%08x Immediate Assignment Downlink (AGCH)\n", tbf->tfi, tbf->tlli);
+		pcu_l1if_tx_agch(immediate_assignment, plen);
+	}
+	else
+	{
+		LOGP(DRLCMAC, LOGL_INFO, "TX: START TFI: %u TLLI: 0x%08x Immediate Assignment Downlink (PCH)\n", tbf->tfi, tbf->tlli);
+		pcu_l1if_tx_pch(immediate_assignment, plen, imsi);
+	}
 	bitvec_free(immediate_assignment);
 }
 
@@ -1813,14 +1821,14 @@ void gprs_rlcmac_trigger_downlink_assignment(struct gprs_rlcmac_tbf *tbf,
 	tbf_timer_stop(tbf);
 
 	/* check for downlink tbf:  */
-	if (old_tbf) {
+	if (old_tbf&&(old_tbf->direction == GPRS_RLCMAC_UL_TBF)) {
 #ifdef DEBUG_DL_ASS_IDLE
 		LOGP(DRLCMAC, LOGL_ERROR, "We must wait for current TBF to be "
 			"released.\n");
 		/* wait one second until assignment */
 		tbf_timer_start(tbf, 1234, 1,0);
 #else
-		LOGP(DRLCMAC, LOGL_DEBUG, "Send dowlink assignment on "
+		LOGP(DRLCMAC, LOGL_INFO, "Send dowlink assignment on "
 			"PACCH, because %s TBF=%d exists for TLLI=0x%08x\n",
 			(old_tbf->direction == GPRS_RLCMAC_UL_TBF)
 				? "UL" : "DL", old_tbf->tfi, old_tbf->tlli);
@@ -1836,7 +1844,12 @@ void gprs_rlcmac_trigger_downlink_assignment(struct gprs_rlcmac_tbf *tbf,
 	} else {
 		LOGP(DRLCMAC, LOGL_DEBUG, "Send dowlink assignment for TBF=%d on PCH, no TBF exist (IMSI=%s)\n", tbf->tfi, imsi);
 		if (!imsi || strlen(imsi) < 3) {
-			LOGP(DRLCMAC, LOGL_ERROR, "No valid IMSI!\n");
+			LOGP(DRLCMAC, LOGL_ERROR, "No IMSI! Use AGCH\n");
+			tbf_new_state(tbf, GPRS_RLCMAC_ASSIGN);
+			tbf->state_flags |= (1 << GPRS_RLCMAC_FLAG_CCCH);
+			/* send immediate assignment */
+			gprs_rlcmac_downlink_assignment(tbf, 0, NULL);
+			tbf->dir.dl.wait_confirm = 1;
 			return;
 		}
 		/* change state */
